==> mx-packageinstaller-pkglist_18.12.06.tar.xz: mx-packageinstaller-pkglist/albanian_firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Albanian_Firefox
</name>

<description>
   <am>Albanian localisation of Firefox</am>
   <ca>Localització de Firefox en Albanès</ca>
   <cs>Albanian localisation of Firefox</cs>
   <da>Albansk oversættelse af Firefox</da>
   <de>Albanische Lokalisierung von Firefox</de>
   <el>Αλβανικός εντοπισμός του Firefox</el>
   <en>Albanian localisation of Firefox</en>
   <es>Localización Albania de Firefox</es>
   <fi>Albanian localisation of Firefox</fi>
   <fr>Localisation albanaise pour Firefox</fr>
   <hi>Albanian localisation of Firefox</hi>
   <hr>Albanska lokalizacija Firefoxa</hr>
   <hu>Albanian localisation of Firefox</hu>
   <is>Albanian localisation of Firefox</is>
   <it>Localizzazione albanese di Firefox</it>
   <ja>Albanian localisation of Firefox</ja>
   <kk>Albanian localisation of Firefox</kk>
   <lt>Albanian localisation of Firefox</lt>
   <nl>Albanese lokalisatie van Firefox</nl>
   <pl>Albanian localisation of Firefox</pl>
   <pt_BR>Albanês Localização para Firefox</pt_BR>
   <pt>Albanês Localização para Firefox</pt>
   <ro>Albanian localisation of Firefox</ro>
   <ru>Albanian localisation of Firefox</ru>
   <sk>Albanian localisation of Firefox</sk>
   <sq>Albanian localisation of Firefox</sq>
   <sv>Albansk lokalisering av Firefox</sv>
   <tr>Albanian localisation of Firefox</tr>
   <uk>Albanian localisation of Firefox</uk>
   <zh_TW>Albanian localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-sq
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-sq
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.03.01.tar.xz: mx-packageinstaller-pkglist/albanian_firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Albanian_Firefox
</name>

<description>
   <am>Albanian localisation of Firefox</am>
   <ar>Albanian localisation of Firefox</ar>
   <bg>Albanian localisation of Firefox</bg>
   <ca>Localització de Firefox en Albanès</ca>
   <cs>Albanian localisation of Firefox</cs>
   <da>Albansk oversættelse af Firefox</da>
   <de>Albanische Lokalisierung von Firefox</de>
   <el>Αλβανικός εντοπισμός του Firefox</el>
   <en>Albanian localisation of Firefox</en>
   <es>Localización Albania de Firefox</es>
   <et>Albanian localisation of Firefox</et>
   <eu>Albanian localisation of Firefox</eu>
   <fa>Albanian localisation of Firefox</fa>
   <fi>Albanian localisation of Firefox</fi>
   <fr>Localisation albanaise pour Firefox</fr>
   <he_IL>Albanian localisation of Firefox</he_IL>
   <hi>Albanian localisation of Firefox</hi>
   <hr>Albanska lokalizacija Firefoxa</hr>
   <hu>Albanian localisation of Firefox</hu>
   <id>Albanian localisation of Firefox</id>
   <is>Albanian localisation of Firefox</is>
   <it>Localizzazione albanese di Firefox</it>
   <ja_JP>Albanian localisation of Firefox</ja_JP>
   <ja>Albanian localisation of Firefox</ja>
   <kk>Albanian localisation of Firefox</kk>
   <ko>Albanian localisation of Firefox</ko>
   <lt>Albanian localisation of Firefox</lt>
   <mk>Albanian localisation of Firefox</mk>
   <nb>Albanian localisation of Firefox</nb>
   <nl>Albanese lokalisatie van Firefox</nl>
   <pl>Albanian localisation of Firefox</pl>
   <pt_BR>Albanês Localização para Firefox</pt_BR>
   <pt>Albanês Localização para Firefox</pt>
   <ro>Albanian localisation of Firefox</ro>
   <ru>Albanian localisation of Firefox</ru>
   <sk>Albanian localisation of Firefox</sk>
   <sl>Albanian localisation of Firefox</sl>
   <sq>Albanian localisation of Firefox</sq>
   <sr>Albanian localisation of Firefox</sr>
   <sv>Albansk lokalisering av Firefox</sv>
   <tr>Albanian localisation of Firefox</tr>
   <uk>Albanian локалізація Firefox</uk>
   <zh_CN>Albanian localisation of Firefox</zh_CN>
   <zh_TW>Albanian localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-sq
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-sq
</uninstall_package_names>
</app>
